@@ -13,6 +13,8 @@ from ..models.strex_transaction import StrexTransaction
 from ..models.status_codes import StatusCodes
 from ..models.detailed_status_codes import DetailedStatusCodes
 from ..models.oneclick_config import OneClickConfig
+from ..models.strex_registration_sms import StrexRegistrationSms
+from ..models.user_validity import UserValidity
 
 
 @pytest.fixture
@@ -174,7 +176,7 @@ def test_out_message_export(client):
     from_date = "2020-08-22T00:00:00Z"
     to_date = "2020-08-23T00:00:00Z"
     csv = client.get_out_message_export(from_date, to_date)
-    assert csv.startswith("SendTime,Sender,Recipient,MessageParts,StatusCode,DetailedStatusCode,Operator,Tags") is True
+    assert csv.startswith("SendTime,Sender,Recipient,RecipientPrefix,MessageParts,StatusCode,DetailedStatusCode,Operator,Tags") is True
 
 def test_prepare_msisdns(client):
     client.prepare_msisdns(["+4798079008"])
@@ -235,14 +237,17 @@ def test_strex_transaction_sequence(client, random_transaction_id):
 
     assert strex_transaction.detailedStatusCode == DetailedStatusCodes.DELIVERED
 
-    # delete_strex_transaction will wait up to 20 secs if trans isn't finished
-    client.delete_strex_transaction(random_transaction_id)
+    # reverse_strex_transaction will wait up to 20 secs if trans isn't finished
+    client.reverse_strex_transaction(random_transaction_id)
 
     # reversal transaction id is always original id prefixed by '-'
     reversal_transaction = client.get_strex_transaction("-" + random_transaction_id)
     
     assert reversal_transaction.statusCode == StatusCodes.REVERSED
 
+def test_user_validity(client):
+    validity = client.get_strex_user_info("mer_test", "+4799031520")
+    assert validity == UserValidity.Full
 
 def test_get_server_public_key(client):
     public_key = client.get_server_public_key('2017-11-17')
@@ -273,13 +278,15 @@ def test_create_oneclick_config(client):
 				"onlineText": "Buy directly",
 				"offlineText": "Buy with PIN-code",
 				"redirectUrl": "https://tempuri.org/php",
+        "subscriptionPrice": 99,
+        "subscriptionInterval": "monthly",
+        "subscriptionStartSms": "Thanks for donating 99kr each month.",
 				"recurring": False,
 				"isRestricted": False,
 				"age": 0,
     }
 
     config = OneClickConfig(**config_data)
-
     client.save_oneclick_config(config)
 
 
@@ -295,6 +302,18 @@ def test_get_one_time_password(client, transaction_id):
     assert one_time_password.transactionId == transaction_id
 
 
+def test_send_strex_registration_sms(client, random_transaction_id):
+    data = {
+				"transactionId": random_transaction_id,
+        "recipient": "+4798079008",
+				"merchantId": "mer_test",
+        "smsText": "Please register as a Strex-custom to continue.",
+    }
+
+    strex_registration_sms = StrexRegistrationSms(**data)
+    client.send_strex_registration_sms(strex_registration_sms)
+    
+
 # Formats datetime object into utc string
 # got from https://stackoverflow.com/q/19654578/1241791
 def _format_datetime(d):
